@@ -37,16 +37,49 @@ if build_gtk2:
 else:
     gi.require_version("Gtk", "3.0")
 
+gi.require_version("MatePanelApplet", "4.0")
+
 from gi.repository import Gtk
-import cairo
-import math
+from gi.repository import Gdk
+from gi.repository import MatePanelApplet
+from gi.repository import GdkPixbuf
+
+from random import randint
+
+from docked_app_helpers import DefaultBackgroundDrawer, AlphaFillBackgroundDrawer, DefaultLightInd,\
+     DefaultDarkInd, ThemeBarInd
 
 
 class IndicatorType:
     """Class to define the indicator types"""
-    LIGHT = 0
-    DARK = 1
+    LIGHT = 0   # Light Circle
+    DARK = 1    # Dark Circle
     NONE = 2
+    TBAR = 3    # Theme Bar
+
+
+class ActiveBgType:
+    """Class to define the active icon background types"""
+    GRADIENT = 0
+    ALPHAFILL = 1
+
+
+def create_frame(caption):
+    """ Convenience function to create a Gtk.Frame with a desired caption
+        in bold text
+
+    Returns:
+        frame - the Gtk.Frame we created
+
+    """
+
+    frame = Gtk.Frame(label="aaaa")
+    lbl = frame.get_label_widget()
+    lbl.set_use_markup(True)
+    lbl.set_label("<b>%s</b>" % caption)
+    frame.set_shadow_type(Gtk.ShadowType.NONE)
+    frame.set_border_width(4)
+    return frame
 
 
 class DockPrefsWindow(Gtk.Window):
@@ -63,7 +96,7 @@ class DockPrefsWindow(Gtk.Window):
 
     """
 
-    def __init__(self, ok_callback):
+    def __init__(self, ok_callback, app):
         """ Constructor for the preferences window
 
         Create the window and its contents and display them
@@ -73,16 +106,23 @@ class DockPrefsWindow(Gtk.Window):
         Args:
             ok_callback : the method to be called when the ok button is
                           is pressed
+            app         : a docked_app from which we can generate previews of the
+                          various indicator and background settings
 
         """
 
         super().__init__(title="Preferences")
 
-        self.DA_SIZE = 32    # the size of the drawing areas for the light and
-                             # dark indicators
+        self.set_position(Gtk.WindowPosition.CENTER_ALWAYS)
+
+        self.PREVIEW_SIZE = 48    # the size of the preview of indicator and background settings
 
         self.connect("delete-event", self.win_delete_event)
 
+        self.__app = app
+
+        self.__app_pb = app.app_pb.scale_simple(self.PREVIEW_SIZE - 6, self.PREVIEW_SIZE - 6,
+                                                GdkPixbuf.InterpType.BILINEAR)
         # setup the window contents
         self.set_border_width(5)
         if build_gtk2:
@@ -99,14 +139,10 @@ class DockPrefsWindow(Gtk.Window):
             self.__hbox1.set_orientation(Gtk.Orientation.HORIZONTAL)
         self.__hbox1.set_spacing(2)
 
-        if build_gtk2:
-            self.__vbox = Gtk.VBox()
-        else:
-            self.__vbox = Gtk.Box()
-            self.__vbox.set_orientation(Gtk.Orientation.VERTICAL)
+        self.__vbox = self.create_vbox
         self.__vbox.set_spacing(2)
 
-        self.__cancel_btn = Gtk.Button(label=("Cancel1"),
+        self.__cancel_btn = Gtk.Button(label="Cancel",
                                        stock=Gtk.STOCK_CANCEL)
         self.__cancel_btn.connect("button-press-event",
                                   self.win_cancel_button_press)
@@ -125,97 +161,127 @@ class DockPrefsWindow(Gtk.Window):
         self.__hbbx.pack_start(self.__cancel_btn, False, False, 4)
         self.__notebook = Gtk.Notebook()
 
-        self.__frame_ind_type = self.create_frame("Indicator Type")
-        self.__rb_light_ind = Gtk.RadioButton(label="Light (for dark panels)")
+        if build_gtk2:
+            self.__appearance_tbl = Gtk.Table(rows=4, columns=1,
+                                              homogeneous=False)
+        else:
+            self.__appearance_tbl = Gtk.Grid()
+            self.__appearance_tbl.set_column_spacing(4)
+            self.__appearance_tbl.set_row_spacing(4)
+            self.__appearance_tbl.set_row_homogeneous(False)
+
+        self.__frame_ind_type = create_frame("Indicator Type")
+        self.__rb_light_ind = Gtk.RadioButton(label="Default light")
         self.__rb_dark_ind = Gtk.RadioButton(group=self.__rb_light_ind,
-                                             label="Dark (for light panels)")
+                                             label="Default Dark")
+        self.__rb_bar_ind = Gtk.RadioButton(group=self.__rb_light_ind,
+                                            label="Single bar")
         self.__rb_no_ind = Gtk.RadioButton(group=self.__rb_light_ind,
                                            label="None - don't use indicators")
         self.__rb_no_ind.connect("toggled", self.rb_no_ind_toggled)
-        self.__da_light_ind = Gtk.DrawingArea()
-        self.__da_light_ind.set_size_request(self.DA_SIZE, self.DA_SIZE)
 
-        # connect an event handler to draw the light indicator
+        # connect event handlers so that we can update the preview when settings
+        # are changed
+        self.__rb_light_ind.connect("toggled", self.setting_toggled)
+        self.__rb_dark_ind.connect("toggled", self.setting_toggled)
+        self.__rb_bar_ind.connect("toggled", self.rb_no_ind_toggled)
+
+        self.__frame_preview = create_frame("Preview")
+        self.__frame_preview.set_shadow_type(Gtk.ShadowType.NONE)
+        self.__hbox_preview = self.create_hbox
+        self.__hbox_preview.set_spacing(0)
+
+        self.__da_pad1 = Gtk.DrawingArea()
+        self.__da_pad1.set_size_request(self.PREVIEW_SIZE, self.PREVIEW_SIZE)
+        self.__da_pad2 = Gtk.DrawingArea()
+        self.__da_pad2.set_size_request(self.PREVIEW_SIZE, self.PREVIEW_SIZE)
         if build_gtk2:
-            self.__da_light_ind.connect("expose-event", self.draw_light_ind)
+            self.__da_pad1.connect("expose-event", self.draw_da_pad)
+            self.__da_pad2.connect("expose-event", self.draw_da_pad)
         else:
-            self.__da_light_ind.connect("draw", self.draw_light_ind)
+            self.__da_pad1.connect("draw", self.draw_da_pad)
+            self.__da_pad2.connect("draw", self.draw_da_pad)
 
-        self.__da_dark_ind = Gtk.DrawingArea()
-        self.__da_dark_ind.set_size_request(self.DA_SIZE, self.DA_SIZE)
+        self.__da_preview = Gtk.DrawingArea()
+        self.__da_preview.set_size_request(self.PREVIEW_SIZE, self.PREVIEW_SIZE)
+
+        self.__frame_preview_align = Gtk.Alignment(xalign=0.5, yalign=0.5,
+                                                   xscale=1.0, yscale=1.0)
+        self.__frame_preview_align.set_padding(0, 0, 12, 0)
+        self.__hbox_preview.pack_start(self.__da_pad1, False, False, 0)
+        self.__hbox_preview.pack_start(self.__da_preview, False, False, 0)
+        self.__hbox_preview.pack_start(self.__da_pad2, False, False, 0)
+        self.__frame_preview_align.add(self.__hbox_preview)
+        self.__vbox_preview = self.create_vbox
+        self.__vbox.set_spacing(2)
+        self.__vbox_preview.pack_start(self.__frame_preview_align, False, False, 4)
+        self.__frame_preview.add(self.__vbox_preview)
 
         # connect an event handler to draw the dark indicator
         if build_gtk2:
-            self.__da_dark_ind.connect("expose-event", self.draw_dark_ind)
+            self.__da_preview.connect("expose-event", self.draw_preview)
         else:
-            self.__da_dark_ind.connect("draw", self.draw_dark_ind)
+            self.__da_preview.connect("draw", self.draw_preview)
 
         # create ui elements for multiple indicators for open windows
         self.__cb_multi_ind = Gtk.CheckButton(label="Display an indicator for each open window")
         self.__cb_multi_ind.set_tooltip_text("Display an indicator (max 4) for each open window")
+        self.__cb_multi_ind.connect("toggled", self.setting_toggled)
 
-        if build_gtk2:
-            self.__table_ind_type = Gtk.Table(rows=3, columns=2,
-                                              homogeneous=False)
-        else:
-            self.__table_ind_type = Gtk.Grid()
-            self.__table_ind_type.set_column_spacing(4)
-            self.__table_ind_type.set_row_spacing(4)
-            self.__table_ind_type.set_row_homogeneous(True)
+        self.__vbox_ind_type = self.create_vbox
+        self.__vbox_ind_type.set_spacing(2)
+        self.__vbox_ind_type.add(self.__rb_light_ind)
+        self.__vbox_ind_type.add(self.__rb_dark_ind)
+        self.__vbox_ind_type.add(self.__rb_bar_ind)
+        self.__vbox_ind_type.add(self.__rb_no_ind)
 
-        # add the indicator type ui elements to the table
-        if build_gtk2:
-            self.__table_ind_type.attach(self.__rb_light_ind, 0, 1, 0, 1,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-
-            self.__table_ind_type.attach(self.__da_light_ind, 1, 2, 0, 1,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-
-            self.__table_ind_type.attach(self.__rb_dark_ind, 0, 1, 1, 2,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-
-            self.__table_ind_type.attach(self.__da_dark_ind, 1, 2, 1, 2,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-            self.__table_ind_type.attach(self.__rb_no_ind, 0, 1, 2, 3,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-        else:
-            self.__table_ind_type.attach(self.__rb_light_ind, 0, 0, 1, 1)
-            self.__table_ind_type.attach(self.__da_light_ind, 1, 0, 1, 1)
-            self.__table_ind_type.attach(self.__rb_dark_ind, 0, 1, 1, 1)
-            self.__table_ind_type.attach(self.__da_dark_ind, 1, 1, 1, 1)
-            self.__table_ind_type.attach(self.__rb_no_ind, 0, 2, 3, 1)
-
-        # make sure the indicator type ui elements are aligned properly
         self.__frame_ind_type_align = Gtk.Alignment(xalign=0.5, yalign=0.5,
                                                     xscale=1.0, yscale=1.0)
         self.__frame_ind_type_align.set_padding(0, 0, 12, 0)
-        self.__frame_ind_type_align.add(self.__table_ind_type)
+        self.__frame_ind_type_align.add(self.__vbox_ind_type)
         self.__frame_ind_type.add(self.__frame_ind_type_align)
 
-        if build_gtk2:
-            self.__ind_vbox = Gtk.VBox()
-            self.__ind_vbox.set_spacing(2)
-            self.__ind_vbox.pack_start(self.__frame_ind_type, False, False, 4)
-            self.__ind_vbox.pack_start(self.__cb_multi_ind, False, False, 4)
-        else:
-            self.__ind_vbox = Gtk.Grid()
-            self.__ind_vbox.set_column_spacing(6)
-            self.__ind_vbox.set_row_spacing(6)
-            self.__ind_vbox.attach(self.__frame_ind_type, 0, 0, 1, 1)
-            self.__ind_vbox.attach(self.__cb_multi_ind, 0, 1, 1, 1)
+        self.__frame_bg = create_frame("Active icon background")
+        self.__rb_grad_bg = Gtk.RadioButton(label="Gradient fill")
+        self.__rb_fill_bg = Gtk.RadioButton(group=self.__rb_grad_bg,
+                                            label="Solid fill")
+        self.__rb_grad_bg.connect("toggled", self.setting_toggled)
+        self.__rb_fill_bg.connect("toggled", self.setting_toggled)
 
-        self.__frame_unpinned_apps = self.create_frame("Unpinned applications")
-        self.__rb_unpinned_all_ws = Gtk.RadioButton (label="Display unpinned apps from all workspaces")
+        self.__vbox_bg_type = self.create_vbox
+        self.__vbox_bg_type.add(self.__rb_grad_bg)
+        self.__vbox_bg_type.add(self.__rb_fill_bg)
+        self.__frame_bg_align = Gtk.Alignment(xalign=0.5, yalign=0.5,
+                                              xscale=1.0, yscale=1.0)
+        self.__frame_bg_align.set_padding(0, 0, 12, 0)
+        self.__frame_bg_align.add(self.__vbox_bg_type)
+        self.__frame_bg.add(self.__frame_bg_align)
+
+        if build_gtk2:
+            self.__appearance_tbl.attach(self.__frame_preview, 0, 1, 0, 1,
+                                         Gtk.AttachOptions.FILL,
+                                         Gtk.AttachOptions.SHRINK,
+                                         2, 2)
+            self.__appearance_tbl.attach(self.__frame_ind_type, 0, 1, 1, 2,
+                                         Gtk.AttachOptions.FILL,
+                                         Gtk.AttachOptions.SHRINK,
+                                         2, 2)
+            self.__appearance_tbl.attach(self.__cb_multi_ind, 0, 1, 2, 3,
+                                         Gtk.AttachOptions.FILL,
+                                         Gtk.AttachOptions.SHRINK,
+                                         2, 2)
+            self.__appearance_tbl.attach(self.__frame_bg, 0, 1, 3, 4,
+                                         Gtk.AttachOptions.FILL,
+                                         Gtk.AttachOptions.SHRINK,
+                                         2, 2)
+        else:
+            self.__appearance_tbl.attach(self.__frame_preview, 0, 0, 1, 1)
+            self.__appearance_tbl.attach(self.__frame_ind_type, 0, 1, 1, 1)
+            self.__appearance_tbl.attach(self.__cb_multi_ind, 0, 2, 1, 1)
+            self.__appearance_tbl.attach(self.__frame_bg, 0, 3, 1, 1)
+
+        self.__frame_unpinned_apps = create_frame("Unpinned applications")
+        self.__rb_unpinned_all_ws = Gtk.RadioButton(label="Display unpinned apps from all workspaces")
         self.__rb_unpinned_cur_ws = Gtk.RadioButton(group=self.__rb_unpinned_all_ws,
                                     label="Display unpinned apps only from current workspace")
 
@@ -249,20 +315,15 @@ class DockPrefsWindow(Gtk.Window):
 
         self.__cb_win_cur_ws = Gtk.CheckButton(label="Display indicators/window list items for current workspace only")
 
-        if build_gtk2:
-            self.__ws_vbox = Gtk.VBox()
-        else:
-            self.__ws_vbox = Gtk.Box()
-            self.__ws_vbox.set_orientation(Gtk.Orientation.VERTICAL)
-
+        self.__ws_vbox = self.create_vbox
         self.__ws_vbox.set_spacing(2)
         self.__ws_vbox.pack_start(self.__frame_unpinned_apps, False, False, 4)
         self.__ws_vbox.pack_start(self.__cb_win_cur_ws, False, False, 4)
 
-        self.__frame_win_sel = self.create_frame("Window selection")
-        self.__rb_win_list = Gtk.RadioButton (label="From applet's window list")
-        self.__rb_win_thumb = Gtk.RadioButton(group=self.__rb_win_list, \
-                                                label="From window thumbnail previews (requires Compiz)")
+        self.__frame_win_sel = create_frame("Window selection")
+        self.__rb_win_list = Gtk.RadioButton(label="From applet's window list")
+        self.__rb_win_thumb = Gtk.RadioButton(group=self.__rb_win_list,
+                                              label="From window thumbnail previews (requires Compiz)")
         self.__table_win_sel = Gtk.Table(rows=2, columns=1,
                                          homogeneous=False)
         self.__table_win_sel.attach(self.__rb_win_list,
@@ -281,33 +342,40 @@ class DockPrefsWindow(Gtk.Window):
         self.__frame_win_sel_align.set_padding(0, 0, 12, 0)
         self.__frame_win_sel_align.add(self.__table_win_sel)
         self.__frame_win_sel.add(self.__frame_win_sel_align)
-        if build_gtk2:
-            self.__win_sel_vbox = Gtk.VBox()
-        else:
-            self.__win_sel_vbox = Gtk.Box()
-            self.__win_sel_vbox.set_orientation(Gtk.Orientation.VERTICAL)
 
+        self.__win_sel_vbox = self.create_vbox
         self.__win_sel_vbox.set_spacing(2)
         self.__win_sel_vbox.pack_start(self.__frame_win_sel, False,
                                        False, 4)
 
-        self.__frame_color_change = self.create_frame("Panel colour")
+        self.__frame_color_change = create_frame("Panel colour")
         self.__cb_panel_color_change = Gtk.CheckButton(label="Change panel colour to match wallpaper")
         self.__cb_panel_color_change.connect("toggled", self.color_change_toggled)
         self.__cb_dock_panel_only = Gtk.CheckButton(label="Change colour of dock's panel only")
 
-        self.__table_color_change = Gtk.Table(rows=2, columns=1,
-                                              homogeneous=False)
-        self.__table_color_change.attach(self.__cb_panel_color_change,
-                                         0, 1, 0, 1,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
-        self.__table_color_change.attach(self.__cb_dock_panel_only,
-                                         0, 1, 1, 2,
-                                         Gtk.AttachOptions.FILL,
-                                         Gtk.AttachOptions.SHRINK,
-                                         2, 2)
+        if build_gtk2:
+            self.__table_color_change = Gtk.Table(rows=2, columns=1,
+                                                  homogeneous=False)
+            self.__table_color_change.attach(self.__cb_panel_color_change,
+                                             0, 1, 0, 1,
+                                             Gtk.AttachOptions.FILL,
+                                             Gtk.AttachOptions.SHRINK,
+                                             2, 2)
+            self.__table_color_change.attach(self.__cb_dock_panel_only,
+                                             0, 1, 1, 2,
+                                             Gtk.AttachOptions.FILL,
+                                             Gtk.AttachOptions.SHRINK,
+                                             2, 2)
+
+        else:
+            self.__table_color_change = Gtk.Grid()
+            self.__table_color_change.set_row_spacing(2)
+            self.__table_color_change.set_column_spacing(2)
+
+            self.__table_color_change.attach(self.__cb_panel_color_change,
+                                             0, 0, 1, 1)
+            self.__table_color_change.attach(self.__cb_dock_panel_only,
+                                             0, 1, 1, 1)
 
         self.__frame_color_change_align = Gtk.Alignment(xalign=0.5, yalign=0.5,
                                                         xscale=1.0, yscale=1.0)
@@ -315,50 +383,82 @@ class DockPrefsWindow(Gtk.Window):
         self.__frame_color_change_align.add(self.__table_color_change)
         self.__frame_color_change.add(self.__frame_color_change_align)
 
-        self.__cb_pan_act = Gtk.CheckButton(label="Disable popup action list " + \
-                                            "and show app actions\non panel " + \
+        self.__cb_pan_act = Gtk.CheckButton(label="Disable popup action list " +
+                                            "and show app actions\non panel " +
                                             "right click menu only")
 
-        if build_gtk2:
-            self.__panel_vbox = Gtk.VBox()
-        else:
-            self.__panel_vbox = Gtk.Box()
-            self.__panel_vbox.set_orientation(Gtk.Orientation.VERTICAL)
-
+        self.__panel_vbox = self.create_vbox
         self.__panel_vbox.set_spacing(2)
         self.__panel_vbox.pack_start(self.__frame_color_change,
                                      False, False, 4)
         self.__panel_vbox.pack_start(self.__cb_pan_act,
                                      False, False, 4)
 
+        self.__frame_fb_bar_col = create_frame("Fallback bar indicator colour")
+        self.__lbl_fb_bar_col = Gtk.Label("Colour")
+        self.__cbtn_fb_bar_col = Gtk.ColorButton()
+        self.__cbtn_fb_bar_col.set_tooltip_text("Colour used for drawing bar indicators when theme colour " +
+                                                "cannot be determined or when using Gtk2")
+
+        self.__fb_bar_col_hbox = self.create_hbox
+        self.__fb_bar_col_hbox.set_spacing(2)
+        self.__fb_bar_col_hbox.pack_start(self.__lbl_fb_bar_col, False, False, 2)
+        self.__fb_bar_col_hbox.pack_start(self.__cbtn_fb_bar_col, True, True, 2)
+        self.__fb_bar_col_vbox = self.create_vbox
+        self.__fb_bar_col_vbox.set_spacing(2)
+        self.__fb_bar_col_vbox.pack_start(self.__fb_bar_col_hbox, False, False, 2)
+        self.__frame_fb_bar_col.add(self.__fb_bar_col_vbox)
+
         self.__vbox.pack_start(self.__notebook, True, True, 4)
-        self.__notebook.append_page(self.__ind_vbox, Gtk.Label("Indicators"))
+        self.__notebook.append_page(self.__appearance_tbl, Gtk.Label("Appearance"))
         self.__notebook.append_page(self.__ws_vbox, Gtk.Label("Workspaces"))
         self.__notebook.append_page(self.__win_sel_vbox, Gtk.Label("Windows"))
         self.__notebook.append_page(self.__panel_vbox,
                                     Gtk.Label("Panel Options"))
+        self.__notebook.append_page(self.__frame_fb_bar_col, Gtk.Label("Misc"))
 
         self.__vbox.pack_start(Gtk.HSeparator(), True, True, 4)
         self.__vbox.pack_start(self.__hbbx, False, False, 0)
+
+        self.set_fallback_bar_col([192, 128, 0])
         self.add(self.__vbox)
         self.show_all()
 
-    def create_frame(self, caption):
-        """ Convenience function to create a Gtk.Frame with a desired caption
-            in bold text
+    @property
+    def create_vbox(self):
+        """
+            Convenience function to create a Gtk2 VBox or a Gtk3 Box
+            oriented vertically
 
         Returns:
-            frame - the Gtk.Frame we created
-
+            the vbox/box we created
         """
 
-        frame = Gtk.Frame(label="aaaa")
-        lbl = frame.get_label_widget()
-        lbl.set_use_markup(True)
-        lbl.set_label("<b>%s</b>" % caption)
-        frame.set_shadow_type(Gtk.ShadowType.NONE)
-        frame.set_border_width(4)
-        return frame
+        if build_gtk2:
+            vbox = Gtk.VBox()
+        else:
+            vbox = Gtk.Box()
+            vbox.set_orientation(Gtk.Orientation.VERTICAL)
+
+        return vbox
+
+    @property
+    def create_hbox(self):
+        """
+            Convenience function to create a Gtk2 HBox or a Gtk3 Box
+            oriented horizontally
+
+        Returns:
+            the hbox/box we created
+        """
+
+        if build_gtk2:
+            hbox = Gtk.HBox()
+        else:
+            hbox = Gtk.Box()
+            hbox.set_orientation(Gtk.Orientation.HORIZONTAL)
+
+        return hbox
 
     def win_delete_event(self, widget, event, data=None):
         """Callback for the preferences window delete event
@@ -379,57 +479,95 @@ class DockPrefsWindow(Gtk.Window):
 
         self.hide()
 
-    def draw_light_ind(self, drawing_area, event):
-        """Draw a light indicator on a dark background"""
+    def draw_da_pad(self, drawing_area, event):
+        """
+            Draw a light or dark background on a drawing area adjacent to the
+            preview, to simulate the look of a panel
+
+         Args:
+
+            drawing_area : our drawing area that caused the event
+            event        : the event parameters
+        """
 
         if build_gtk2:
-            ctx = self.__da_light_ind.window.cairo_create()
+            ctx = drawing_area.window.cairo_create()
         else:
             ctx = event
 
-        ctx.set_source_rgb(0.1, 0.5, 0.5)
-        ctx.rectangle(0, 0, self.DA_SIZE, self.DA_SIZE)
+        if self.__rb_dark_ind.get_active():
+            ctx.set_source_rgb(0.75, 0.75, 0.75)
+        else:
+            ctx.set_source_rgb(0.25, 0.25, 0.25)
+        ctx.rectangle(0, 0, self.PREVIEW_SIZE, self.PREVIEW_SIZE)
         ctx.fill()
 
-        ctx.set_source_rgb(0.05, 0.05, 0.3)
-        ctx.rectangle(1, 1, self.DA_SIZE-2, self.DA_SIZE-2)
-        ctx.fill()
+    def draw_preview(self, drawing_area, event):
+        """Draw a preview of the current appearance settings
 
-        ind_x = self.DA_SIZE/2
-        ind_y = ind_x
+        Draw a dark or light background to represent the panel
+        Draw an appropriate type of active background
+        Draw an app icon
+        Draw the appropriate type of indicator (or no indicator)
 
-        rad_patt = cairo.RadialGradient(ind_x, ind_y, 2, ind_x, ind_y, 4)
-        rad_patt.add_color_stop_rgba(0, 0.9, 0.9, 0.9, 1)
-        rad_patt.add_color_stop_rgba(1, 0.0, 0.0, 0.0, 0)
-        ctx.set_source(rad_patt)
-        ctx.arc(ind_x, ind_y, 6, 0, 2*math.pi)
-        ctx.fill()
+        Args:
 
-    def draw_dark_ind(self, drawing_area, event):
-        """Draw a dark indicator on a dark background."""
+            drawing_area : our drawing area that caused the event
+            event        : the event parameters
+        """
 
         if build_gtk2:
-            ctx = self.__da_dark_ind.window.cairo_create()
+            ctx = self.__da_preview.window.cairo_create()
         else:
             ctx = event
 
-        ctx.set_source_rgb(0.5, 0.5, 0.5)
-        ctx.rectangle(0, 0, self.DA_SIZE, self.DA_SIZE)
+        # if a dark indicator is set, we draw a light background, otherwise a
+        # dark background
+        if self.__rb_dark_ind.get_active():
+            ctx.set_source_rgb(0.75, 0.75, 0.75)
+        else:
+            ctx.set_source_rgb(0.25, 0.25, 0.25)
+        ctx.rectangle(0, 0, self.PREVIEW_SIZE, self.PREVIEW_SIZE)
         ctx.fill()
 
-        ctx.set_source_rgb(0.1, 0.8, 0.8)
-        ctx.rectangle(1, 1, self.DA_SIZE-2, self.DA_SIZE-2)
-        ctx.fill()
+        # draw the app icon
+        Gdk.cairo_set_source_pixbuf(ctx, self.__app_pb, 3, 3)
+        ctx.paint()
 
-        ind_x = self.DA_SIZE/2
-        ind_y = ind_x
+        # draw the active background - first we need the colour of the background in cairo
+        # values
+        red = self.__app.highlight_color.r / 255
+        green = self.__app.highlight_color.g / 255
+        blue = self.__app.highlight_color.b / 255
 
-        rad_patt = cairo.RadialGradient(ind_x, ind_y, 2, ind_x, ind_y, 4)
-        rad_patt.add_color_stop_rgba(0, 0.0, 0.0, 0.0, 1)
-        rad_patt.add_color_stop_rgba(1, 0.9, 0.9, 0.9, 0)
-        ctx.set_source(rad_patt)
-        ctx.arc(ind_x, ind_y, 6, 0, 2*math.pi)
-        ctx.fill()
+        if self.__rb_grad_bg.get_active():
+            bgd = DefaultBackgroundDrawer(ctx, self.PREVIEW_SIZE,
+                                          MatePanelApplet.AppletOrient.UP, red, green, blue)
+        else:
+            bgd = AlphaFillBackgroundDrawer(ctx, self.PREVIEW_SIZE,
+                                            MatePanelApplet.AppletOrient.UP, red, green, blue, 0.5)
+
+        bgd.draw()
+
+        # draw the indicator(s) if necessary
+        if not self.__rb_no_ind.get_active():
+            # if we're showing indicators for each open window, show multiple indicators
+            if self.__cb_multi_ind.get_active():
+                num_ind = randint(2, 4)
+            else:
+                num_ind = 1
+
+            if self.__rb_light_ind.get_active():
+                ind = DefaultLightInd(ctx, self.PREVIEW_SIZE,
+                                      MatePanelApplet.AppletOrient.UP, num_ind)
+            elif self.__rb_dark_ind.get_active():
+                ind = DefaultDarkInd(ctx, self.PREVIEW_SIZE,
+                                     MatePanelApplet.AppletOrient.UP, num_ind)
+            else:
+                ind = ThemeBarInd(ctx, self.PREVIEW_SIZE, MatePanelApplet.AppletOrient.UP,
+                                  self.__app.applet)
+
+            ind.draw()
 
     def color_change_toggled(self, widget):
         """Handler for the panel color change checkbox toggled event
@@ -441,14 +579,30 @@ class DockPrefsWindow(Gtk.Window):
 
         self.__cb_dock_panel_only.set_sensitive(self.__cb_panel_color_change.get_active())
 
-    def rb_no_ind_toggled(self, widget):
-        """ Handler for the no indicator radio button toggled event
+    def setting_toggled(self, widget):
+        """ Handler for updating the preview when appearance settings are changed
 
-        If the no indicator option is selected, disable the multiple indicator
-        checkbox
+        Args:
+            widget: the widget the caused the event
         """
 
-        self.__cb_multi_ind.set_sensitive(self.__rb_no_ind.get_active() is not True)
+        self.__da_pad1.queue_draw()
+        self.__da_preview.queue_draw()
+        self.__da_pad2.queue_draw()
+
+    def rb_no_ind_toggled(self, widget):
+        """ Handler for the no indicator radio button toggled event, also
+            used by the bar indicator rb
+
+        If either the no indicator or bar indicator ption is selected, disable
+        the multiple indicator checkbox
+
+        Update the appearance preview
+        """
+
+        self.__cb_multi_ind.set_sensitive(self.__rb_no_ind.get_active() is not True and
+                                          self.__rb_bar_ind.get_active() is not True)
+        self.setting_toggled(widget)
 
     def get_indicator_type(self):
         """Get the indicator type specified in the preferences window.
@@ -460,6 +614,8 @@ class DockPrefsWindow(Gtk.Window):
             return IndicatorType.LIGHT
         elif self.__rb_dark_ind.get_active():
             return IndicatorType.DARK
+        elif self.__rb_bar_ind.get_active():
+            return IndicatorType.TBAR
         else:
             return IndicatorType.NONE
 
@@ -473,6 +629,8 @@ class DockPrefsWindow(Gtk.Window):
             self.__rb_light_ind.set_active(True)
         elif indicator == IndicatorType.DARK:
             self.__rb_dark_ind.set_active(True)
+        elif indicator == IndicatorType.TBAR:
+            self.__rb_bar_ind.set_active(True)
         else:
             self.__rb_no_ind.set_active(True)
 
@@ -485,6 +643,29 @@ class DockPrefsWindow(Gtk.Window):
 
         return self.__cb_multi_ind.get_active()
 
+    def set_bg(self, bg):
+        """ Set the active icon background type
+
+        Args : bg - an ActiveBgType
+        """
+
+        if bg == ActiveBgType.GRADIENT:
+            self.__rb_grad_bg.set_active(True)
+        else:
+            self.__rb_fill_bg.set_active(True)
+
+    def get_bg(self):
+        """ Gets the currently selected active icon background type
+
+        Returns : An ActiveBgType
+
+        """
+
+        if self.__rb_grad_bg.get_active():
+            return ActiveBgType.GRADIENT
+        else:
+            return ActiveBgType.ALPHAFILL
+
     def set_multi_ind(self, use_multi_ind):
         """Sets whether or not to display multiple indicators
 
@@ -625,6 +806,40 @@ class DockPrefsWindow(Gtk.Window):
 
         self.__cb_win_cur_ws.set_active(win_cur_ws_only)
 
+    def set_fallback_bar_col(self, colrgb):
+        """
+            Set the colour of the fallback bar indicator colour button
+
+        Arga:
+            colrgb : a list containing the r,g and b colour components(0-255) as strings
+        """
+
+        colstr = "#%0.2X%0.2X%0.2X" % (int(colrgb[0]), int(colrgb[1]), int(colrgb[2]))
+
+        if build_gtk2:
+            cbrgba = Gdk.color_parse(colstr)
+            self.__cbtn_fb_bar_col.set_color(color=cbrgba)
+        else:
+            cbrgba = Gdk.RGBA()
+            cbrgba.parse(colstr)
+            self.__cbtn_fb_bar_col.set_rgba(cbrgba)
+
+        self.__cbtn_fb_bar_col.set_use_alpha(False)
+
+    def get_fallback_bar_col(self):
+        """
+            Get the colour of the fallback bar indicator colour button
+
+        Returns:
+            a list containing the r, g, and b colour components(0-255)
+        """
+
+        if build_gtk2:
+            cbrgba = self.__cbtn_fb_bar_col.get_color()
+        else:
+            cbrgba = self.__cbtn_fb_bar_col.get_rgba().to_color()
+
+        return ["%s" % int(cbrgba.red / 256), "%s" % int(cbrgba.green / 256), "%s" % int(cbrgba.blue / 256)]
 
 
 def main():
